==> owncloud-10.0.7.tgz: owncloud/settings/l10n/kn.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "No user supplied" : "﻿ಯಾವುದೇ ಬಳಕೆದಾರನ ಹೆಸರನ್ನು ನೀಡಿರುವುದಿಲ್ಲ",
    "Authentication error" : "ದೃಢೀಕರಣ ದೋಷ",
    "Unable to change password" : "﻿ಗುಪ್ತಪದವನ್ನು ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Couldn't send reset email. Please contact your administrator." : "﻿ರೀಸೆಟ್ ಇಮೇಲ್ ಕಳುಹಿಸಲು ಸಾಧ್ಯವಾಗಲಿಲ್ಲ. ನಿಮ್ಮ ನಿರ್ವಾಹಕರನ್ನು ಸಂಪರ್ಕಿಸಿ.",
    "Group already exists." : "﻿ಗುಂಪು ಈಗಾಗಲೇ ಅಸ್ತಿತ್ವದಲ್ಲಿದೆ.",
    "Unable to add group." : "﻿ಗುಂಪುನ್ನು ಸೇರಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ.",
    "Unable to delete group." : "﻿ಗುಂಪುನ್ನು ಅಳಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ.",
    "Saved" : "﻿ಉಳಿಸಿದ",
    "test email settings" : "ಪರೀರ್ಕ್ಷಾತ ﻿ಇ-ಅಂಚೆಯ ಆಯ್ಕೇ",
    "Email sent" : "ಇ-ಅಂಚೆ ಕಳುಹಿಸಲಾಗಿದೆ",
    "You need to set your user email before being able to send test emails." : "ನೀವು ಪರೀಕ್ಷಾ ಇ-ಅಂಚೆಯನ್ನು ಕಳುಹಿಸುವ ಮುನ್ನ ನಿಮ್ಮ ಬಳಕೆದಾರ ಇ-ಅಂಚೆಯನ್ನು  ಹೊಂದಿಸಬೇಕಾಗುತ್ತದೆ.",
    "Invalid mail address" : "﻿ಅಮಾನ್ಯ ಇ-ಅಂಚೆ ವಿಳಾಸ",
    "Unable to create user." : "﻿ಬಳಕೆದಾರನ ಖಾತೆ ರಚಿಸಲು ಸಾಧ್ಯವಾಗಿಲ್ಲ.",
    "Your %s account was created" : "﻿ನಿಮ್ಮ%s ಖಾತೆಯನ್ನು ಸ್ಥಾಪಿಸಲಾಗಿದೆ",
    "Unable to delete user." : "ಬಳಕೆದಾರನ ಹೆಸರುನ್ನು ಅಳಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ.",
    "Forbidden" : "ನಿರ್ಬಂಧಿಸಲಾಗಿದೆ",
    "Invalid user" : "﻿ಅಮಾನ್ಯ ಬಳಕೆದಾರ",
    "Unable to change mail address" : "﻿ಇ-ಅಂಚೆ ವಿಳಾಸ ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Your full name has been changed." : "﻿ನಿಮ್ಮ ಪೂರ್ಣ ಹೆಸರನ್ನು ಬದಲಾಯಿಸಲಾಗಿದೆ.",
    "Unable to change full name" : "﻿ಪೂರ್ಣ ಹೆಸರನ್ನು ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ",
    "__language_name__" : "ಕನ್ನಡ",
    "Language changed" : "﻿ಭಾಷೆಯನ್ನು ಬದಲಾಯಿಸಲಾಗಿದೆ",
    "Invalid request" : "﻿ಅಮಾನ್ಯ ಕೋರಿಕೆ",
    "Admins can't remove themself from the admin group" : "﻿ನಿರ್ವಾಹಕರು ನಿರ್ವಹಣೆ ಗುಂಪಿನಿಂದ ತಮ್ಮನ್ನೇ ತಾವು ತೆಗೆದುಹಾಕಿಕೊಳ್ಳಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Couldn't remove app." : "ಅಳಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "All" : "﻿ಎಲ್ಲಾ",
    "Enabled" : "ಸಕ್ರಿಯಗೊಳಿಸಿದೆ",
    "Not enabled" : "﻿ಸಕ್ರಿಯಗೊಳಿಸಿಲ್ಲ",
    "Please wait...." : "﻿ದಯವಿಟ್ಟು ನಿರೀಕ್ಷಿಸಿ ....",
    "Error while disabling app" : "ಕಾರ್ಯಕ್ರಮವನ್ನು ನಿಷ್ಕ್ರಿಯಗೊಳಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Disable" : "﻿ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಿ",
    "Enable" : "ಸಕ್ರಿಯಗೊಳಿಸು",
    "Error while enabling app" : "ಕಾರ್ಯಕ್ರಮವನ್ನು ಸಕ್ರಿಯಗೊಳಿಸಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Updating...." : "ಆಧುನೀಕರಿಸುಲಾಗುತ್ತಿದೇ ....",
    "Error while updating app" : "ಕಾರ್ಯಕ್ರಮವನ್ನು  ನವೀಕರಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Updated" : "ಆಧುನೀಕರಿಸಲಾಗಿದೆ",
    "Uninstalling ...." : "ಅಳಿಸಿಹಾಕುವುದು ...",
    "Error while uninstalling app" : "ಅಳಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Uninstall" : "ಅಳಿಸಿ",
    "Valid until {date}" : "﻿{date} ವರೆಗೆ ಚಾಲ್ತಿಯಲ್ಲಿರುತ್ತದೆ",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Sending..." : "﻿ಕಳುಹಿಸಲಾಗುತ್ತಿದೆ ...",
    "Select a profile picture" : "ಸಂಕ್ಷಿಪ್ತ ವ್ಯಕ್ತಿಚಿತ್ರ ಒಂದನ್ನು ಆಯ್ಕೆ ಮಾಡಿ",
    "Very weak password" : "ಅತೀ ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "Weak password" : "ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "So-so password" : "ಊಹಿಸಬಹುದಾದ ಗುಪ್ತಪದ",
    "Good password" : "ಉತ್ತಮ ಗುಪ್ತಪದ",
    "Strong password" : "﻿ಪ್ರಬಲ ಗುಪ್ತಪದ",
    "Groups" : "﻿ಗುಂಪುಗಳು",
    "Unable to delete {objName}" : "﻿{objName} ಅಳಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ ",
    "A valid group name must be provided" : "ಮಾನ್ಯ ಗುಂಪಿನ ಹೆಸರನ್ನು ಒದಗಿಸಬೇಕಾಗುತ್ತದೆ",
    "deleted {groupName}" : "﻿ಅಳಿಸಲಾಗಿದೆ {groupName}",
    "undo" : "ಹಿಂದಿರುಗಿಸು",
    "never" : "﻿ಎಂದಿಗೂ",
    "deleted {userName}" : "{userName} ಬಳಕೆಯ ಹೆಸರುನ್ನು  ﻿ಅಳಿಸಲಾಗಿದೆ ﻿",
    "add group" : "﻿ಗುಂಪುನ್ನು ಸೇರಿಸಿ",
    "no group" : "ಯಾವುದೇ ಗುಂಪಿನಲ್ಲಿಲ್ಲ",
    "A valid username must be provided" : "﻿ಮಾನ್ಯ ಬಳಕೆದಾರ ಹೆಸರು ಒದಗಿಸಬೇಕಾಗುತ್ತದೆ",
    "A valid password must be provided" : "ಸರಿಯಾದ ಬಳಕೆದಾರ ಗುಪ್ತಪದ ಒದಗಿಸಬೇಕಾಗಿದೆ",
    "A valid email must be provided" : "﻿ಮಾನ್ಯ ಬಳಕೆದಾರ ಇ-ಅಂಚೆಯನ್ನು ಒದಗಿಸಬೇಕಾಗುತ್ತದೆ",
    "Cheers!" : "ಆನಂದಿಸಿ !",
    "Forum" : "﻿ವೇದಿಕೆ",
    "Documentation:" : "﻿ದಾಖಲೆ:",
    "Enable only for specific groups" : "﻿ಕೇವಲ ನಿರ್ದಿಷ್ಟ ಗುಂಪುಗಳಿಗೆ ಸಕ್ರಿಯಗೊಳಿಸಿ",
    "Uninstall App" : "ಅಳಿಸಿ",
    "Sharing" : "﻿ಹಂಚಿಕೆ",
    "Expire after " : "ನಿಶ್ವಸಿಸುವ ಅವಧಿ",
    "days" : "﻿ದಿನಗಳು",
    "Enforce expiration date" : "﻿ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ಬಲವ೦ತವಾಗಿ ಜಾರಿಗೆ ಮಾಡಿ",
    "Everything (fatal issues, errors, warnings, info, debug)" : "﻿ಎಲ್ಲ ರೀತಿಗಳು (ವಿನಾಶಕ ಸಮಸ್ಯೆಗಳು, ದೋಷಗಳು, ಎಚ್ಚರಿಕೆಗಳನ್ನು, ಮಾಹಿತಿ, ಇತರೆ )",
    "Info, warnings, errors and fatal issues" : "﻿ಮಾಹಿತಿ, ಎಚ್ಚರಿಕೆ, ದೋಷಗಳು ಮತ್ತು ಮಾರಕ ಸಮಸ್ಯೆಗಳು",
    "Warnings, errors and fatal issues" : "﻿ಎಚ್ಚರಿಕೆ, ದೋಷಗಳು ಮತ್ತು ಮಾರಕ ಸಮಸ್ಯೆಗಳು",
    "Errors and fatal issues" : "﻿ದೋಷಗಳು ಮತ್ತು ಮಾರಕ ಸಮಸ್ಯೆಗಳು",
    "Fatal issues only" : "ಮಾರಕ ಸಮಸ್ಯೆಗಳು ಮಾತ್ರ",
    "Log" : "ಹಿನ್ನೆಲೆಯ ದಾಖಲೆ",
    "None" : "﻿ಯಾವುದೂ ಇಲ್ಲ",
    "Login" : "ಖಾತೆ ಪ್ರವೇಶಿಸು",
    "Plain" : "﻿ಸರಳ",
    "Send mode" : "ಕಳುಹಿಸುವ ﻿ಕ್ರಮ",
    "Encryption" : "ರಹಸ್ಯ ಸಂಕೇತೀಕರಿಸು",
    "mail" : "﻿ಅಂಚೆ",
    "Authentication method" : "﻿ದೃಢೀಕರಣ ವಿಧಾನ",
    "Authentication required" : "﻿ದೃಢೀಕರಣ ಅಗತ್ಯವಿದೆ",
    "Server address" : "﻿ಪರಿಚಾರಕ ಗಣಕಯಂತ್ರದ ವಿಳಾಸ",
    "Port" : "﻿ರೇವು",
    "Credentials" : "﻿ರುಜುವಾತುಗಳು",
    "SMTP Username" : "﻿SMTP ಬಳಕೆದಾರ ಹೆಸರು",
    "SMTP Password" : "﻿SMTP ಗುಪ್ತ ಪದ",
    "Test email settings" : "ಪರೀರ್ಕ್ಷಾತ ﻿ಇ-ಅಂಚೆಯ ಆಯ್ಕೇ",
    "Send email" : "ಇ-ಅಂಚೆಯನ್ನು  ಕಳುಹಿಸಿ",
    "Cancel" : "﻿ರದ್ದು",
    "Email" : "﻿ಇ-ಅಂಚೆ",
    "Your email address" : "﻿ನಿಮ್ಮ ಇ-ಅಂಚೆ ವಿಳಾಸ",
    "Password" : "ಗುಪ್ತ ಪದ",
    "Unable to change your password" : "﻿ನಿನ್ನ ಗುಪ್ತಪದವನ್ನು ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Current password" : "ಪ್ರಸ್ತುತ ಗುಪ್ತಪದ",
    "New password" : "﻿ಹೊಸ ಗುಪ್ತಪದ",
    "Change password" : "ಗುಪ್ತ ಪದವನ್ನು ಬದಲಾಯಿಸಿ",
    "Language" : "﻿ಭಾಷೆ",
    "Help translate" : "﻿ಭಾಷಾಂತರಿಸಲು ಸಹಾಯ ಮಾಡಿ",
    "Name" : "﻿ಹೆಸರು",
    "Username" : "﻿ಬಳಕೆಯ ಹೆಸರು",
    "Version" : "﻿ಆವೃತ್ತಿ",
    "Personal" : "﻿ವೈಯಕ್ತಿಕ",
    "Admin" : "﻿ನಿರ್ವಹಕ",
    "Error" : "﻿ತಪ್ಪಾಗಿದೆ",
    "E-Mail" : "ಇ-ಅಂಚೆ ವಿಳಾಸ",
    "Create" : "ಸೃಷ್ಟಿಸಿ",
    "Add Group" : "﻿ಗುಂಪುನ್ನು ಸೇರಿಸಿ",
    "Group" : "﻿ಗುಂಪು",
    "Everyone" : "﻿ಪ್ರತಿಯೊಬ್ಬರೂ",
    "Admins" : "﻿ನಿರ್ವಾಹಕರು",
    "Other" : "﻿ಇತರೆ",
    "Full Name" : "ಪೂರ್ಣ ಹೆಸರು",
    "Quota" : "ಪಾಲು",
    "Storage Location" : "﻿ ಸಂಗ್ರಹ ಸ್ಥಳ",
    "Last Login" : "﻿ಹಿಂದಿನ ಖಾತೆ ಪ್ರವೇಶ",
    "change full name" : "﻿ಪೂರ್ಣ ಹೆಸರು ಬದಲಾಯಿಸಬಹುದು",
    "set new password" : "﻿ಹೊಸ ಗುಪ್ತಪದವನ್ನು ಹೊಂದಿಸಿ",
    "change email address" : "﻿ಇ-ಅಂಚೆ ವಿಳಾಸ ಬದಲಾಯಿಸಿ",
    "Default" : "ಆರಂಭದ ಪ್ರತಿ"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.10.tgz: owncloud/settings/l10n/kn.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "No user supplied" : "﻿ಯಾವುದೇ ಬಳಕೆದಾರನ ಹೆಸರನ್ನು ನೀಡಿರುವುದಿಲ್ಲ",
    "Authentication error" : "ದೃಢೀಕರಣ ದೋಷ",
    "Unable to change password" : "﻿ಗುಪ್ತಪದವನ್ನು ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Couldn't send reset email. Please contact your administrator." : "﻿ರೀಸೆಟ್ ಇಮೇಲ್ ಕಳುಹಿಸಲು ಸಾಧ್ಯವಾಗಲಿಲ್ಲ. ನಿಮ್ಮ ನಿರ್ವಾಹಕರನ್ನು ಸಂಪರ್ಕಿಸಿ.",
    "Group already exists." : "﻿ಗುಂಪು ಈಗಾಗಲೇ ಅಸ್ತಿತ್ವದಲ್ಲಿದೆ.",
    "Unable to add group." : "﻿ಗುಂಪುನ್ನು ಸೇರಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ.",
    "Unable to delete group." : "﻿ಗುಂಪುನ್ನು ಅಳಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ.",
    "Saved" : "﻿ಉಳಿಸಿದ",
    "test email settings" : "ಪರೀರ್ಕ್ಷಾತ ﻿ಇ-ಅಂಚೆಯ ಆಯ್ಕೇ",
    "Email sent" : "ಇ-ಅಂಚೆ ಕಳುಹಿಸಲಾಗಿದೆ",
    "You need to set your user email before being able to send test emails." : "ನೀವು ಪರೀಕ್ಷಾ ಇ-ಅಂಚೆಯನ್ನು ಕಳುಹಿಸುವ ಮುನ್ನ ನಿಮ್ಮ ಬಳಕೆದಾರ ಇ-ಅಂಚೆಯನ್ನು  ಹೊಂದಿಸಬೇಕಾಗುತ್ತದೆ.",
    "Invalid mail address" : "﻿ಅಮಾನ್ಯ ಇ-ಅಂಚೆ ವಿಳಾಸ",
    "Unable to create user." : "﻿ಬಳಕೆದಾರನ ಖಾತೆ ರಚಿಸಲು ಸಾಧ್ಯವಾಗಿಲ್ಲ.",
    "Your %s account was created" : "﻿ನಿಮ್ಮ%s ಖಾತೆಯನ್ನು ಸ್ಥಾಪಿಸಲಾಗಿದೆ",
    "Unable to delete user." : "ಬಳಕೆದಾರನ ಹೆಸರುನ್ನು ಅಳಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ.",
    "Forbidden" : "ನಿರ್ಬಂಧಿಸಲಾಗಿದೆ",
    "Invalid user" : "﻿ಅಮಾನ್ಯ ಬಳಕೆದಾರ",
    "Unable to change mail address" : "﻿ಇ-ಅಂಚೆ ವಿಳಾಸ ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Your full name has been changed." : "﻿ನಿಮ್ಮ ಪೂರ್ಣ ಹೆಸರನ್ನು ಬದಲಾಯಿಸಲಾಗಿದೆ.",
    "Unable to change full name" : "﻿ಪೂರ್ಣ ಹೆಸರನ್ನು ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ",
    "__language_name__" : "ಕನ್ನಡ",
    "Language changed" : "﻿ಭಾಷೆಯನ್ನು ಬದಲಾಯಿಸಲಾಗಿದೆ",
    "Invalid request" : "﻿ಅಮಾನ್ಯ ಕೋರಿಕೆ",
    "Admins can't remove themself from the admin group" : "﻿ನಿರ್ವಾಹಕರು ನಿರ್ವಹಣೆ ಗುಂಪಿನಿಂದ ತಮ್ಮನ್ನೇ ತಾವು ತೆಗೆದುಹಾಕಿಕೊಳ್ಳಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Couldn't remove app." : "ಅಳಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "All" : "﻿ಎಲ್ಲಾ",
    "Enabled" : "ಸಕ್ರಿಯಗೊಳಿಸಿದೆ",
    "Not enabled" : "﻿ಸಕ್ರಿಯಗೊಳಿಸಿಲ್ಲ",
    "Please wait...." : "﻿ದಯವಿಟ್ಟು ನಿರೀಕ್ಷಿಸಿ ....",
    "Error while disabling app" : "ಕಾರ್ಯಕ್ರಮವನ್ನು ನಿಷ್ಕ್ರಿಯಗೊಳಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Disable" : "﻿ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಿ",
    "Enable" : "ಸಕ್ರಿಯಗೊಳಿಸು",
    "Error while enabling app" : "ಕಾರ್ಯಕ್ರಮವನ್ನು ಸಕ್ರಿಯಗೊಳಿಸಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Updating...." : "ಆಧುನೀಕರಿಸುಲಾಗುತ್ತಿದೇ ....",
    "Error while updating app" : "ಕಾರ್ಯಕ್ರಮವನ್ನು  ನವೀಕರಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Updated" : "ಆಧುನೀಕರಿಸಲಾಗಿದೆ",
    "Uninstalling ...." : "ಅಳಿಸಿಹಾಕುವುದು ...",
    "Error while uninstalling app" : "ಅಳಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Uninstall" : "ಅಳಿಸಿ",
    "Valid until {date}" : "﻿{date} ವರೆಗೆ ಚಾಲ್ತಿಯಲ್ಲಿರುತ್ತದೆ",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Sending..." : "﻿ಕಳುಹಿಸಲಾಗುತ್ತಿದೆ ...",
    "Select a profile picture" : "ಸಂಕ್ಷಿಪ್ತ ವ್ಯಕ್ತಿಚಿತ್ರ ಒಂದನ್ನು ಆಯ್ಕೆ ಮಾಡಿ",
    "Very weak password" : "ಅತೀ ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "Weak password" : "ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "So-so password" : "ಊಹಿಸಬಹುದಾದ ಗುಪ್ತಪದ",
    "Good password" : "ಉತ್ತಮ ಗುಪ್ತಪದ",
    "Strong password" : "﻿ಪ್ರಬಲ ಗುಪ್ತಪದ",
    "Groups" : "﻿ಗುಂಪುಗಳು",
    "Unable to delete {objName}" : "﻿{objName} ಅಳಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ ",
    "A valid group name must be provided" : "ಮಾನ್ಯ ಗುಂಪಿನ ಹೆಸರನ್ನು ಒದಗಿಸಬೇಕಾಗುತ್ತದೆ",
    "deleted {groupName}" : "﻿ಅಳಿಸಲಾಗಿದೆ {groupName}",
    "undo" : "ಹಿಂದಿರುಗಿಸು",
    "never" : "﻿ಎಂದಿಗೂ",
    "deleted {userName}" : "{userName} ಬಳಕೆಯ ಹೆಸರುನ್ನು  ﻿ಅಳಿಸಲಾಗಿದೆ ﻿",
    "add group" : "﻿ಗುಂಪುನ್ನು ಸೇರಿಸಿ",
    "no group" : "ಯಾವುದೇ ಗುಂಪಿನಲ್ಲಿಲ್ಲ",
    "A valid username must be provided" : "﻿ಮಾನ್ಯ ಬಳಕೆದಾರ ಹೆಸರು ಒದಗಿಸಬೇಕಾಗುತ್ತದೆ",
    "A valid password must be provided" : "ಸರಿಯಾದ ಬಳಕೆದಾರ ಗುಪ್ತಪದ ಒದಗಿಸಬೇಕಾಗಿದೆ",
    "A valid email must be provided" : "﻿ಮಾನ್ಯ ಬಳಕೆದಾರ ಇ-ಅಂಚೆಯನ್ನು ಒದಗಿಸಬೇಕಾಗುತ್ತದೆ",
    "Cheers!" : "ಆನಂದಿಸಿ !",
    "Forum" : "﻿ವೇದಿಕೆ",
    "Documentation:" : "﻿ದಾಖಲೆ:",
    "Enable only for specific groups" : "﻿ಕೇವಲ ನಿರ್ದಿಷ್ಟ ಗುಂಪುಗಳಿಗೆ ಸಕ್ರಿಯಗೊಳಿಸಿ",
    "Uninstall App" : "ಅಳಿಸಿ",
    "Sharing" : "﻿ಹಂಚಿಕೆ",
    "Expire after " : "ನಿಶ್ವಸಿಸುವ ಅವಧಿ",
    "days" : "﻿ದಿನಗಳು",
    "Enforce expiration date" : "﻿ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ಬಲವ೦ತವಾಗಿ ಜಾರಿಗೆ ಮಾಡಿ",
    "Everything (fatal issues, errors, warnings, info, debug)" : "﻿ಎಲ್ಲ ರೀತಿಗಳು (ವಿನಾಶಕ ಸಮಸ್ಯೆಗಳು, ದೋಷಗಳು, ಎಚ್ಚರಿಕೆಗಳನ್ನು, ಮಾಹಿತಿ, ಇತರೆ )",
    "Info, warnings, errors and fatal issues" : "﻿ಮಾಹಿತಿ, ಎಚ್ಚರಿಕೆ, ದೋಷಗಳು ಮತ್ತು ಮಾರಕ ಸಮಸ್ಯೆಗಳು",
    "Warnings, errors and fatal issues" : "﻿ಎಚ್ಚರಿಕೆ, ದೋಷಗಳು ಮತ್ತು ಮಾರಕ ಸಮಸ್ಯೆಗಳು",
    "Errors and fatal issues" : "﻿ದೋಷಗಳು ಮತ್ತು ಮಾರಕ ಸಮಸ್ಯೆಗಳು",
    "Fatal issues only" : "ಮಾರಕ ಸಮಸ್ಯೆಗಳು ಮಾತ್ರ",
    "Log" : "ಹಿನ್ನೆಲೆಯ ದಾಖಲೆ",
    "None" : "﻿ಯಾವುದೂ ಇಲ್ಲ",
    "Login" : "ಖಾತೆ ಪ್ರವೇಶಿಸು",
    "Plain" : "﻿ಸರಳ",
    "Send mode" : "ಕಳುಹಿಸುವ ﻿ಕ್ರಮ",
    "Encryption" : "ರಹಸ್ಯ ಸಂಕೇತೀಕರಿಸು",
    "mail" : "﻿ಅಂಚೆ",
    "Authentication method" : "﻿ದೃಢೀಕರಣ ವಿಧಾನ",
    "Authentication required" : "﻿ದೃಢೀಕರಣ ಅಗತ್ಯವಿದೆ",
    "Server address" : "﻿ಪರಿಚಾರಕ ಗಣಕಯಂತ್ರದ ವಿಳಾಸ",
    "Port" : "﻿ರೇವು",
    "Credentials" : "﻿ರುಜುವಾತುಗಳು",
    "SMTP Username" : "﻿SMTP ಬಳಕೆದಾರ ಹೆಸರು",
    "SMTP Password" : "﻿SMTP ಗುಪ್ತ ಪದ",
    "Test email settings" : "ಪರೀರ್ಕ್ಷಾತ ﻿ಇ-ಅಂಚೆಯ ಆಯ್ಕೇ",
    "Send email" : "ಇ-ಅಂಚೆಯನ್ನು  ಕಳುಹಿಸಿ",
    "Cancel" : "﻿ರದ್ದು",
    "Email" : "﻿ಇ-ಅಂಚೆ",
    "Your email address" : "﻿ನಿಮ್ಮ ಇ-ಅಂಚೆ ವಿಳಾಸ",
    "Password" : "ಗುಪ್ತ ಪದ",
    "Unable to change your password" : "﻿ನಿನ್ನ ಗುಪ್ತಪದವನ್ನು ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Current password" : "ಪ್ರಸ್ತುತ ಗುಪ್ತಪದ",
    "New password" : "﻿ಹೊಸ ಗುಪ್ತಪದ",
    "Change password" : "ಗುಪ್ತ ಪದವನ್ನು ಬದಲಾಯಿಸಿ",
    "Language" : "﻿ಭಾಷೆ",
    "Help translate" : "﻿ಭಾಷಾಂತರಿಸಲು ಸಹಾಯ ಮಾಡಿ",
    "Name" : "﻿ಹೆಸರು",
    "Username" : "﻿ಬಳಕೆಯ ಹೆಸರು",
    "Version" : "﻿ಆವೃತ್ತಿ",
    "Personal" : "﻿ವೈಯಕ್ತಿಕ",
    "Admin" : "﻿ನಿರ್ವಹಕ",
    "Error" : "﻿ತಪ್ಪಾಗಿದೆ",
    "E-Mail" : "ಇ-ಅಂಚೆ ವಿಳಾಸ",
    "Create" : "ಸೃಷ್ಟಿಸಿ",
    "Add Group" : "﻿ಗುಂಪುನ್ನು ಸೇರಿಸಿ",
    "Group" : "﻿ಗುಂಪು",
    "Everyone" : "﻿ಪ್ರತಿಯೊಬ್ಬರೂ",
    "Admins" : "﻿ನಿರ್ವಾಹಕರು",
    "Other" : "﻿ಇತರೆ",
    "Full Name" : "ಪೂರ್ಣ ಹೆಸರು",
    "Quota" : "ಪಾಲು",
    "Storage Location" : "﻿ ಸಂಗ್ರಹ ಸ್ಥಳ",
    "Last Login" : "﻿ಹಿಂದಿನ ಖಾತೆ ಪ್ರವೇಶ",
    "change full name" : "﻿ಪೂರ್ಣ ಹೆಸರು ಬದಲಾಯಿಸಬಹುದು",
    "set new password" : "﻿ಹೊಸ ಗುಪ್ತಪದವನ್ನು ಹೊಂದಿಸಿ",
    "change email address" : "﻿ಇ-ಅಂಚೆ ವಿಳಾಸ ಬದಲಾಯಿಸಿ",
    "Default" : "ಆರಂಭದ ಪ್ರತಿ",
    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ",
    "Add" : "﻿ಸೇರಿಸಿ"
},
"nplurals=1; plural=0;");
